import stylelint from "stylelint";
import {isNumber,isBoolean,isString,isArray,isObject,some,isNaN} from "lodash";

export function validProps(props) {

  if (isBoolean(props)) { return true; }
  if (isNaN(props)) { return false; }
  if (isNumber(props)) { return true; }
  if (isString(props)) {
    if (!props) { return false; }
    if (props === "false") { return false; }
    if (props.match(/undefined|\bnull\b|\[object Object\]|NaN/)) { return false; }
    return true;
  }
  if (isArray(props) || isObject(props)) {
    return !some(props,(val)=>!validProps(val));
  }
  return false;
}

export function validateCSS(code) {

  if (code.match(/undefined/i)) {
    console.log("'undefined' found in css code")
    return false;
  }

  if (code.match(/null/i)) {
    console.log("'null' found in css code")
    return false;
  }

  if (code.match(/\[object/i)) {
    console.log("'[object' found in css code")
    return false;
  }

  return stylelint.lint({
    code,
    config: {
      extends: "stylelint-config-standard",
      rules: {
        "function-comma-space-after": null,
        "rule-empty-line-before": null,
        indentation: null,
        "selector-list-comma-newline-after": null,
        "no-missing-end-of-source-newline": null,
        "color-hex-length": null,
        "number-leading-zero": null,
      }
    },
  })
  .then(({errored,results})=>{
    if (errored) {
      console.log("stylelint warnings",results[0].warnings); //eslint-disable-line no-console
      return false;
    }
    return true;
  });
}
