import {fuse} from "./utils";
import {validProps} from "./test-utils";

describe("test-utils",()=>{
  describe("validProps",()=>{
    it("should return true for a number",()=>{
      expect(validProps(3)).toBe(true);
    });
    it("should return true for 0",()=>{
      expect(validProps(0)).toBe(true);
    });
    it("should return true for booleans",()=>{
      expect(validProps(true)).toBe(true);
      expect(validProps(false)).toBe(true);
    });
    it("should return false for nullish",()=>{
      expect(validProps(null)).toBe(false);
      expect(validProps(undefined)).toBe(false);
    });
    it("should return true for strings",()=>{
      expect(validProps("foobar")).toBe(true);
    });
    it("should return false for zero length strings",()=>{
      expect(validProps("")).toBe(false);
    });
    it("should return false for strings containing the word 'null'",()=>{
      expect(validProps("null")).toBe(false);
      expect(validProps("something null")).toBe(false);
      expect(validProps("null something")).toBe(false);
      expect(validProps("something null something")).toBe(false);
    });
    it("should return true for strings containing 'null' within a word",()=>{
      expect(validProps("babananull")).toBe(true);
      expect(validProps("nullbabana")).toBe(true);
    });
    it("should return false for strings containing the 'undefined'",()=>{
      expect(validProps("undefined")).toBe(false);
      expect(validProps("something undefined")).toBe(false);
      expect(validProps("undefined something")).toBe(false);
      expect(validProps("something undefined something")).toBe(false);
      expect(validProps("somethingundefinedsomething")).toBe(false);
    });
    it("should return false for strings containing the 'NaN'",()=>{
      expect(validProps(1 / "hamster")).toBe(false);
      expect(validProps("NaN")).toBe(false);
      expect(validProps("#NaNNaNNaN")).toBe(false);
    });
    it("should return false for strings containing object strings",()=>{
      expect(validProps("[object Object]")).toBe(false);
      expect(validProps("something [object Object]")).toBe(false);
      expect(validProps("[object Object] something")).toBe(false);
      expect(validProps("something [object Object] something")).toBe(false);
      expect(validProps("something[object Object]something")).toBe(false);
    });
    it("should validate valid arrays",()=>{
      expect(validProps(["one",2,true])).toBe(true);
    });
    it("should invalidate invalid arrays",()=>{
      expect(validProps(["one",null,true])).toBe(false);
    });
    it("should validate valid objects",()=>{
      expect(validProps({one: "one",two: 2,three: true})).toBe(true);
    });
    it("should invalidate invalid objects",()=>{
      expect(validProps({one: "one",two: 2,three: ""})).toBe(false);
      expect(validProps({one: "one",two: "null",three: "three"})).toBe(false);
    });

    const testData = {
      one: ["one","two","three"],
      two: true,
      three: {
        one: ["one","two","three"],
        two: false,
        three: "three",
        four: 4,
      }
    };

    it("should validate nested props",()=>{
      expect(validProps(testData)).toBe(true);
    });

    it("should invalidate nested props",()=>{
      const invalidData = fuse({},testData,{
        three: {
          four: "undefined"
        }
      });
      expect(validProps(invalidData)).toBe(false);
    });

  });
});
