import {multiply,parseUnitValue,fuse} from "./utils";

describe("utils",()=>{

  describe("parseUnitValue",()=>{
    it("should work with units",()=>{
      expect(parseUnitValue("1px")).toEqual({unit: "px",value: 1});
    });
    it("should work with numbers",()=>{
      expect(parseUnitValue(2)).toEqual({unit: "",value: 2});
    });
    it("should fail gracefully with nonsense",()=>{
      expect(parseUnitValue("hamster")).toEqual({unit: "",value: 0});
      expect(parseUnitValue({foo: "bar"})).toEqual({unit: "",value: 0});
    });
  });

  describe("multiply",()=>{
    it("should handle number values",()=>{
      expect(multiply(1,2,2)).toBe("4");
    });
    it("should handle string values",()=>{
      expect(multiply("2","3","3")).toBe("18");
    });
    it("should handle units",()=>{
      expect(multiply("2px","2","3")).toBe("12px");
      expect(multiply("2","4px","3")).toBe("24px");
      expect(multiply("1","2","3px")).toBe("6px");
    });
    it("should handle mixed units",()=>{
      expect(multiply("2px","2em","3rem")).toBe("12px");
      expect(multiply("2","2em","3rem")).toBe("12em");
    });
    it("should handle percentage units",()=>{
      expect(multiply("50%","2")).toBe("100%");
    });
    it("should handle multi percentages",()=>{
      expect(multiply("50%","50%")).toBe("25%");
    });
    it("should handle mixed units with percentages",()=>{
      expect(multiply("50%","24px")).toBe("12px");
    });
    it("should fail gracefully with stupid values",()=>{
      expect(multiply("foo","bar","hamster")).toBe("0");
      expect(multiply("foo","bar","1px")).toBe("0px");
    });
  });

  describe("fuse",()=>{
    it("should replace arrays from source objects",()=>{
      const fused = fuse(
        {
          foo: {
            bar: [1,2,3],
          }
        },
        {
          foo: {
            bar: [5],
          }
        }
      );
      expect(fused.foo.bar.length).toBe(1);
      expect(fused.foo.bar[0]).toBe(5);
    });
  });
});
