// Base class
//
// Kickstart any navigation component with a set of style resets. Works with
// `<nav>`s or `<ul>`s.

import {merge} from "lodash";

import getProps from "../lib/get-props";

import {nav} from "../variables";

import {borderRadius} from "./mixins/border-radius";
import {hoverFocus} from "./mixins/hover";


export function navBase(themeProps) {

  const {navProps} = getProps(themeProps,{nav});

  return [
    {
      className: "nav-item",
    },
    {
      className: "nav",
      display: "flex",
      flexWrap: "wrap",
      paddingLeft: 0,
      marginBottom: 0,
      listStyle: "none",
      "& $nav-item": {
        listStyleType: "none", // not in Bootstrap - more robust
      }
    },
    {
      className: "nav-vertical", // not from Bootstrap
      flexDirection: "column",
    },
    merge(
      {
        className: "nav-link",
        display: "block",
        padding: `${navProps.linkPaddingY} ${navProps.linkPaddingX}`,
      },
      hoverFocus(themeProps,{
        textDecoration: "none",
      }),
      {
        "&.disabled": {
          color: navProps.linkDisabledColor,
        }
      }
    ),
  ];
}

//
// Tabs
//

// .nav-tabs {
//   border-bottom: $nav-tabs-border-width solid $nav-tabs-border-color;
//
//   .nav-item {
//     margin-bottom: -$nav-tabs-border-width;
//   }
//
//   .nav-link {
//     border: $nav-tabs-border-width solid transparent;
//     @include border-top-radius($nav-tabs-border-radius);
//
//     @include hover-focus {
//       border-color: $nav-tabs-link-hover-border-color $nav-tabs-link-hover-border-color $nav-tabs-border-color;
//     }
//
//     &.disabled {
//       color: $nav-link-disabled-color;
//       background-color: transparent;
//       border-color: transparent;
//     }
//   }
//
//   .nav-link.active,
//   .nav-item.show .nav-link {
//     color: $nav-tabs-link-active-color;
//     background-color: $nav-tabs-link-active-bg;
//     border-color: $nav-tabs-link-active-border-color $nav-tabs-link-active-border-color $nav-tabs-link-active-bg;
//   }
//
//   .dropdown-menu {
//     // Make dropdown border overlap tab border
//     margin-top: -$nav-tabs-border-width;
//     // Remove the top rounded corners here since there is a hard edge above the menu
//     @include border-top-radius(0);
//   }
// }


//
// Pills
//

export function navPills(themeProps) {

  const {navProps} = getProps(themeProps,{nav});

  return [
    {
      className: "nav-link",
    },
    {
      className: "show",
    },
    {
      className: "active",
    },
    {
      className: "nav-pills",
      "& $nav-link": borderRadius(navProps.pillsBorderRadius),
      "& $nav-link$active, & $show > $nav-link": {
        color: navProps.pillsLinkActiveColor,
        backgroundColor: navProps.pillsLinkActiveBG,
      },
    },
  ];
}



//
// Justified variants
//

export function navJustified() {
  return [
    {
      className: "nav-item",
    },
    {
      className: "nav-fill" ,
      "& $nav-item": {
        flex: "1 1 auto",
        textAlign: "center",
      }
    },

    {
      className: "nav-justified",
      "& $nav-item": {
        flexBasis: 0,
        flexGrow: 1,
        textAlign: "center",
      }
    }
  ];
}


// Tabbable tabs
//
// Hide tabbable panes to start, show them when `.active`

// .tab-content {
//   > .tab-pane {
//     display: none;
//   }
//   > .active {
//     display: block;
//   }
// }
